@@ -1,8 +1,5 @@
 package System::Command::Reaper;
-{
-  $System::Command::Reaper::VERSION = '1.106';
-}
-
+$System::Command::Reaper::VERSION = '1.108';
 use strict;
 use warnings;
 use 5.006;
@@ -37,7 +34,7 @@ sub is_terminated {
     my $pid = $self->{pid};
 
     # Zed's dead, baby. Zed's dead.
-    return $pid if !$_is_alive->($pid) and exists $self->{command}{exit};
+    return $pid if !$_is_alive->($pid) and exists $self->{exit};
 
     # If that is a re-animated body, we're gonna have to kill it.
     return $self->_reap(WNOHANG);
@@ -47,19 +44,19 @@ sub _reap {
     my ( $self, @flags ) = @_;
     my $pid = $self->{pid};
 
-    if ( my $reaped = waitpid( $pid, @flags )
-        and !exists $self->{command}{exit} )
-    {
+    # REPENT/THE END IS/EXTREMELY/FUCKING/NIGH
+    if ( my $reaped = waitpid( $pid, @flags ) and !exists $self->{exit} ) {
         my $zed = $reaped == $pid;
         carp "Child process already reaped, check for a SIGCHLD handler"
-            if !$zed && !$System::Command::QUIET;
+            if !$zed && !$System::Command::QUIET && !MSWin32;
 
+        # What do you think? "Zombie Kill of the Week"?
         @{$self}{ STATUS() }
             = $zed
             ? ( $? >> 8, $? & 127, $? & 128 )
             : ( -1, -1, -1 );
 
-        # does our creator still exist?
+        # Who died and made you fucking king of the zombies?
         @{ $self->{command} }{ STATUS() } = @{$self}{ STATUS() }
             if defined $self->{command};
 
@@ -98,11 +95,11 @@ sub DESTROY {
 
 =head1 NAME
 
-System::Command::Reaper
+System::Command::Reaper - Reap processes started by System::Command
 
 =head1 VERSION
 
-version 1.106
+version 1.108
 
 =head1 SYNOPSIS
 
@@ -144,20 +141,20 @@ care of reaping the child process when the original L<System::Command>
 and its filehandles have been destroyed (or when L<System::Command>
 C<close()> method is being called).
 
-=head1 NAME
-
-System::Command::Reaper - Reap processes started by System::Command
-
 =head1 METHODS
 
 System::Command::Reaper supports the following methods:
 
-=head2 new( $command )
+=head2 new
+
+    my $reaper = System::Command::Reaper->new( $cmd );
 
 Create a new System::Command::Reaper object attached to the
 L<System::Command> object passed as a parameter.
 
-=head2 close()
+=head2 close
+
+    $reaper->close();
 
 Close all the opened filehandles of the main L<System::Command> object,
 reaps the child process, and updates the main object with the status
@@ -165,7 +162,9 @@ information of the child process.
 
 C<DESTROY> calls C<close()> when the sentinel is being destroyed.
 
-=head2 is_terminated()
+=head2 is_terminated
+
+    if ( $reaper->is_terminated ) {...}
 
 Returns a true value if the underlying process was terminated.
 
@@ -195,3 +194,5 @@ under the same terms as Perl itself.
 
 __END__
 
+# ABSTRACT: Reap processes started by System::Command
+
